@@ -10,6 +10,16 @@ from tests.tools import make_auth, make_db, make_storage
 from tests.config import TEST_USER_EMAIL, TEST_USER_PASSWORD
 
 
+@pytest.fixture(scope='session')
+def auth():
+	return make_auth()
+
+
+@pytest.fixture(scope='session')
+def auth_admin():
+	return make_auth(True)
+
+
 @pytest.fixture(scope='session')
 def db():
 	# To make it easier to test, we keep the test restricted to firebase_tests
@@ -20,11 +30,6 @@ def db():
 		make_db(service_account=True).child('firebase_tests').remove()
 
 
-@pytest.fixture(scope='session')
-def auth():
-	return make_auth(True)
-
-
 @pytest.fixture(scope='session')
 def email():
 	return TEST_USER_EMAIL
