@@ -2,7 +2,7 @@
 #   Licensed under MIT (https://github.com/AsifArmanRahman/firebase/blob/main/LICENSE)
 
 # --------------------------------------------------------------------------------------
-
+import os.path
 
 import pytest
 
@@ -18,6 +18,10 @@ class TestStorage:
 	def test_get_url(self, storage):
 		assert storage.child('firebase-test-001').child('uploaded-file.txt').get_url(None)
 
+	def test_download(self, storage):
+		assert storage.child('firebase-test-001').child('uploaded-file.txt').download('tests/static/downloaded.txt') is None
+		assert os.path.exists('tests/static/downloaded.txt')
+
 	def test_delete(self, storage):
 		assert storage.delete('firebase-test-001/uploaded-file.txt', None) is None
 
